package com.uas.platform.warehouse.backend.api;

import com.uas.platform.warehouse.backend.transport.entity.BaseVoucher;
import com.uas.platform.warehouse.backend.transport.service.NotificationService;
import com.uas.platform.warehouse.backend.transport.service.PullDataService;
import com.uas.platform.warehouse.core.common.ResultBean;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.data.web.PageableDefault;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Http interface for operating post back(reply).
 *
 * @author huxz
 */
@RestController
@RequestMapping(value = "/api")
public class ReplyController {

  private final NotificationService notificationService;

  private final PullDataService pullDataService;

  @Autowired
  public ReplyController(
      NotificationService notificationService,
      PullDataService pullDataService) {
    this.notificationService = notificationService;
    this.pullDataService = pullDataService;
  }

  /**
   * Gain specific notification from enterprise customer by pagination.
   *
   * @param pageInfo  pagination info
   * @return  response data using unified data format
   */
  @GetMapping(value = "/gain-notice", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<List<BaseVoucher>> gainNotificationFromEnterprise(
      @PageableDefault(size = 50) Pageable pageInfo) {
    return new ResultBean<List<BaseVoucher>>(pullDataService.gainNotificationFromEnterprise(pageInfo));
  }
}
