package com.uas.platform.warehouse.backend.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import org.joda.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 出货单明细，用于出货通知.
 *
 * @author huxz
 */
@Entity
@Table(name = "shipment_detail")
@JsonInclude(Include.NON_EMPTY)
public class ShipmentDetail {

  @Id
  @GeneratedValue
  @Column(name = "id")
  @JsonIgnore
  private Long id;

  /**
   * 出货单号.
   */
  @Column(name = "pull_no")
  private String pullNo;

  /**
   * 出货单行号.
   */
  @Column(name = "pull_line_no")
  private String pullLineNo;

  /**
   * 物料号.
   */
  @Column(name = "prod_code")
  private String prodCode;

  /**
   * 出货数量.
   */
  @Column(name = "out_qty")
  private int outQty;

  /**
   * 批次号.
   */
  @Column(name = "batchCode")
  private String batchCode;

  /**
   * 客户物料号.
   */
  @Column(name = "cust_prod_code")
  private String custProdCode;

  /**
   * 客户PO号.
   */
  @Column(name = "po_code")
  private String poCode;

  /**
   * 客户型号.
   */
  @Column(name = "cust_prod_spec")
  private String custProdSpec;

  /**
   * 销售单价.
   */
  @Column(name = "sales_price")
  private Double salesPrice;

  /**
   * 物料规格.
   */
  @Column(name = "spec")
  private String spec;

  /**
   * 采购币别.
   */
  @Column(name = "pur_currency")
  private String purCurrency;

  /**
   * 备用字段1.
   */
  @Column(name = "attribute1",columnDefinition = "TEXT")
  private String attribute1;

  /**
   * 备用字段2.
   */
  @Column(name = "attribute2",columnDefinition = "TEXT")
  private String attribute2;

  /**
   * 备用字段3.
   */
  @Column(name = "attribute3",columnDefinition = "TEXT")
  private String attribute3;

  /**
   * 操作时间
   */
  @Column(name = "operate_time")
  @JsonIgnore
  private Date operateTime = LocalDateTime.now().toDate();

  public ShipmentDetail() {
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getPullLineNo() {
    return pullLineNo;
  }

  public void setPullLineNo(String pullLineNo) {
    this.pullLineNo = pullLineNo;
  }

  public String getProdCode() {
    return prodCode;
  }

  public void setProdCode(String prodCode) {
    this.prodCode = prodCode;
  }

  public int getOutQty() {
    return outQty;
  }

  public void setOutQty(int outQty) {
    this.outQty = outQty;
  }

  public String getBatchCode() {
    return batchCode;
  }

  public void setBatchCode(String batchCode) {
    this.batchCode = batchCode;
  }

  public String getCustProdCode() {
    return custProdCode;
  }

  public void setCustProdCode(String custProdCode) {
    this.custProdCode = custProdCode;
  }

  public String getPoCode() {
    return poCode;
  }

  public void setPoCode(String poCode) {
    this.poCode = poCode;
  }

  public String getCustProdSpec() {
    return custProdSpec;
  }

  public void setCustProdSpec(String custProdSpec) {
    this.custProdSpec = custProdSpec;
  }

  public Double getSalesPrice() {
    return salesPrice;
  }

  public void setSalesPrice(Double salesPrice) {
    this.salesPrice = salesPrice;
  }

  public String getSpec() {
    return spec;
  }

  public void setSpec(String spec) {
    this.spec = spec;
  }

  public String getPullNo() {
    return pullNo;
  }

  public void setPullNo(String pullNo) {
    this.pullNo = pullNo;
  }

  public String getAttribute1() {
    return attribute1;
  }

  public void setAttribute1(String attribute1) {
    this.attribute1 = attribute1;
  }

  public String getAttribute2() {
    return attribute2;
  }

  public void setAttribute2(String attribute2) {
    this.attribute2 = attribute2;
  }

  public String getAttribute3() {
    return attribute3;
  }

  public void setAttribute3(String attribute3) {
    this.attribute3 = attribute3;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }

  public String getPurCurrency() {
    return purCurrency;
  }

  public void setPurCurrency(String purCurrency) {
    this.purCurrency = purCurrency;
  }

  public Date getOperateTime() {
    return operateTime;
  }

  public void setOperateTime(Date operateTime) {
    this.operateTime = operateTime;
  }
}
